==> uim_0.4.5+r1576.orig.tar.gz: uim-0.4.5+r1576/uim/uim-util.h <==
/*
  uim-util.h utility function prototypes for uim.

  Copyright (c) 2004 uim Project http://uim.freedesktop.org/

  All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:

  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
  3. Neither the name of authors nor the names of its contributors
     may be used to endorse or promote products derived from this software
     without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
  ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  SUCH DAMAGE.

*/

#ifndef _uim_util_h_included_
#define _uim_util_h_included_

#ifdef __cplusplus
extern "C" {
#endif

/**
 *  *
 * @param localename locale string. typical format of this string
 * is ll_CC.charset. E.G. for Japanese locale, ja_JP.EUC-JP
 * ll is language code defined in ISO 639, CC is country code defined
 * in ISO 3166.
 * @return language name string. (Now it's untranslated.)
 *
 * @see uim_create_context
 */
const char *
uim_get_language_name_from_locale(const char *localename);

#ifdef __cplusplus
}
#endif
#endif

==> uim_1.4.1.orig.tar.gz: uim-1.4.1/uim/uim-util.h <==
/*
  uim-util.h utility function prototypes for uim.

  Copyright (c) 2004-2007 uim Project http://uim.freedesktop.org/

  All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:

  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
  3. Neither the name of authors nor the names of its contributors
     may be used to endorse or promote products derived from this software
     without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS'' AND
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
  ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE
  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  SUCH DAMAGE.

*/

#ifndef _uim_util_h_included_
#define _uim_util_h_included_

#ifdef __cplusplus
extern "C" {
#endif

/**
 *  *
 * @param localename locale string. typical format of this string
 * is ll_CC.charset. E.G. for Japanese locale, ja_JP.EUC-JP
 * ll is language code defined in ISO 639, CC is country code defined
 * in ISO 3166.
 * @return language name string. (Now it's untranslated.)
 *
 * @see uim_create_context
 */
const char *
uim_get_language_name_from_locale(const char *localename);

const char *
uim_get_language_code_from_language_name(const char *language_name);

/* uim's iconv_open wrapper */
void *uim_iconv_open(const char *tocode, const char *fromcode);

#ifdef __cplusplus
}
#endif
#endif
